Module: SmartlingXcode

Defined in:
lib/smartling_xcode.rb,
lib/smartling_xcode/backend.rb,
lib/smartling_xcode/version.rb

Defined Under Namespace

Classes: API, Project

Constant Summary collapse

VERSION =
"0.1.6"
USAGE =
"Smartling utility to extract strings from an Xcode project \nand add them to a Smartling project.\nVersion \#{VERSION}\n\nUsage:\n  smartling_xcode command [project_path] [-v version]\n  smartling_xcode -h/--help\n\nCommands:\n  init        Configure the current folder with Smartling\n              project credentials to be able to push \n              strings.\n  extract     Extract all strings from the Xcode project \n              and print out the list of .strings files.\n  push        Extract all strings from the Xcode project \n              and send them to your Smartling project.\n\nOptions:\n  project_path   Specify a path for the Xcode project. \n                 Uses the first .xcodeproj file in the \n                 current directory by default.\n  -v version     Specify an app version for the strings \n                 files upload. Uses the version found in \n                 the project's info.plist file by default, \n                 but will prompt for a choice if multiple \n                 plist files are found.\n  -s             Use the sandbox server.\n\n"